summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/samples/qstring-slot.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/samples/qstring-slot.cs')
-rw-r--r--qtsharp/src/examples/samples/qstring-slot.cs20
1 files changed, 10 insertions, 10 deletions
diff --git a/qtsharp/src/examples/samples/qstring-slot.cs b/qtsharp/src/examples/samples/qstring-slot.cs
index e6d5110a..e33fa1b3 100644
--- a/qtsharp/src/examples/samples/qstring-slot.cs
+++ b/qtsharp/src/examples/samples/qstring-slot.cs
@@ -1,4 +1,4 @@
// Demo of a QString slot
// Implemented by Marcus Urban
using System;
@@ -6,21 +6,21 @@ using Qt;
public class MyWidget : QVBox
{
- QLineEdit lineEdit;
- QLabel label;
+ TQLineEdit lineEdit;
+ TQLabel label;
- public MyWidget (QWidget parent, String name) : base (parent, name)
+ public MyWidget (TQWidget parent, String name) : base (parent, name)
{
- lineEdit = new QLineEdit( this, "lineEdit" );
- label = new QLabel( this, "label" );
+ lineEdit = new TQLineEdit( this, "lineEdit" );
+ label = new TQLabel( this, "label" );
label.SetText("Default");
- QObject.Connect( lineEdit, SIGNAL("textChanged(QString)"),
- label, "SetText(QString)" );
+ TQObject.Connect( lineEdit, TQT_SIGNAL("textChanged(TQString)"),
+ label, "SetText(TQString)" );
}
- public MyWidget (QWidget parent) : this (parent, "") {}
+ public MyWidget (TQWidget parent) : this (parent, "") {}
public MyWidget () : this (null, "") {}
}
@@ -28,7 +28,7 @@ public class Example {
public static int Main (String[] args)
{
- QApplication a = new QApplication (args);
+ TQApplication a = new TQApplication (args);
MyWidget w = new MyWidget ();
a.SetMainWidget (w);
@@ -1,4 +1,4 @@
-// Demo of a QString slot
+// Demo of a TQString slot
// Implemented by Marcus Urban
using System;